@@ -7,7 +7,6 @@ use crate::*;
 
 /// Accounts for [gauge::gauge_commit_vote].
 #[derive(Accounts)]
-#[instruction(vote_bump: u8)]
 pub struct GaugeCommitVote<'info> {
     /// The [Gaugemeister].
     pub gaugemeister: Account<'info, Gaugemeister>,
@@ -33,7 +32,7 @@ pub struct GaugeCommitVote<'info> {
             gauge_vote.key().as_ref(),
             epoch_gauge_voter.voting_epoch.to_le_bytes().as_ref(),
         ],
-        bump = vote_bump,
+        bump,
         payer = payer
     )]
     pub epoch_gauge_vote: Account<'info, EpochGaugeVote>,
